from a10sdk.common.A10BaseClass import A10BaseClass


class Monitor(A10BaseClass):
    
    """Class Description::
    Define the Health Monitor object.

    Class monitor supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param sample_threshold: {"description": "Number of samples in one epoch above which passive HC is enabled. If below or equal to the threshold, passive HC is disabled (Specify number of samples in one second (Default is 50). If the number of samples is 0, no action is taken)", "format": "number", "default": 50, "optional": true, "maximum": 10000, "minimum": 1, "type": "number"}
    :param override_ipv4: {"optional": true, "type": "string", "description": "Override implicitly inherited IPv4 address from target", "format": "ipv4-address"}
    :param retry: {"description": "Specify the Healthcheck Retries (Retry Count (default 3))", "format": "number", "optional": true, "maximum": 10, "minimum": 1, "default-depends-on": "health.global::retry", "type": "number"}
    :param name: {"description": "Monitor Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 29, "type": "string"}
    :param strict_retry_on_server_err_resp: {"default": 0, "optional": true, "type": "number", "description": "Require strictly retry", "format": "flag"}
    :param passive_interval: {"description": "Interval to do manual health checking while in passive mode (Specify value in seconds (Default is 10 s))", "format": "number", "default": 10, "optional": true, "maximum": 180, "minimum": 1, "type": "number"}
    :param override_port: {"description": "Override implicitly inherited port from target (Port number (1-65534))", "format": "number", "type": "number", "maximum": 65534, "minimum": 1, "optional": true}
    :param up_retry: {"description": "Specify the Healthcheck Retries before declaring target up (Up-retry count (default 1))", "format": "number", "optional": true, "maximum": 10, "minimum": 1, "default-depends-on": "health.global::up-retry", "type": "number"}
    :param interval: {"description": "Specify the Healthcheck Interval (Interval Value, in seconds (default 5))", "format": "number", "optional": true, "maximum": 180, "minimum": 1, "default-depends-on": "health.global::interval", "type": "number"}
    :param passive: {"default": 0, "optional": true, "type": "number", "description": "Specify passive mode", "format": "flag"}
    :param override_ipv6: {"optional": true, "type": "string", "description": "Override implicitly inherited IPv6 address from target", "format": "ipv6-address"}
    :param timeout: {"description": "Specify the Healthcheck Timeout (Timeout Value, in seconds(default 5), Timeout should be less than or equal to interval)", "format": "number", "optional": true, "maximum": 180, "minimum": 1, "default-depends-on": "health.global::timeout", "type": "number"}
    :param threshold: {"description": "Threshold percentage above which passive mode is enabled (Specify percentage (Default is 75%))", "format": "number", "default": 75, "optional": true, "maximum": 100, "minimum": 0, "type": "number"}
    :param disable_after_down: {"default": 0, "optional": true, "type": "number", "description": "Disable the target if health check failed", "format": "flag"}
    :param status_code: {"optional": true, "enum": ["status-code-2xx", "status-code-non-5xx"], "type": "string", "description": "'status-code-2xx': Enable passive mode with 2xx http status code; 'status-code-non-5xx': Enable passive mode with non-5xx http status code; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/health/monitor/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "monitor"
        self.a10_url="/axapi/v3/health/monitor/{name}"
        self.DeviceProxy = ""
        self.sample_threshold = ""
        self.override_ipv4 = ""
        self.retry = ""
        self.name = ""
        self.strict_retry_on_server_err_resp = ""
        self.passive_interval = ""
        self.override_port = ""
        self.up_retry = ""
        self.interval = ""
        self.passive = ""
        self.override_ipv6 = ""
        self.timeout = ""
        self.threshold = ""
        self.disable_after_down = ""
        self.method = {}
        self.status_code = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Tcp(A10BaseClass):
    
    """Class Description::
    L4 TCP switch config.

    Class tcp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param initial_window_size: {"description": "Set the initial window size (number)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param alive_if_active: {"default": 0, "optional": true, "type": "number", "description": "keep connection alive if active traffic", "format": "flag"}
    :param qos: {"description": "QOS level (number)", "format": "number", "type": "number", "maximum": 63, "minimum": 1, "optional": true}
    :param name: {"description": "Fast TCP Template Name", "format": "string", "default": "default", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param reset_fwd: {"default": 0, "optional": true, "type": "number", "description": "send reset to server if error happens", "format": "flag"}
    :param half_open_idle_timeout: {"description": "TCP Half Open Idle Timeout (sec), default off (half open idle timeout in second, default off)", "format": "number", "type": "number", "maximum": 60, "minimum": 1, "optional": true}
    :param idle_timeout: {"description": "Idle Timeout value (default 120 seconds) (idle timeout in second, default 120)", "format": "number", "type": "number", "maximum": 2097151, "minimum": 1, "optional": true}
    :param force_delete_timeout: {"description": "The maximum time that a session can stay in the system before being delete (number (second))", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "not": "force-delete-timeout-100ms", "type": "number"}
    :param lan_fast_ack: {"default": 0, "optional": true, "type": "number", "description": "Enable fast TCP ack on LAN", "format": "flag"}
    :param insert_client_ip: {"default": 0, "optional": true, "type": "number", "description": "Insert client ip into TCP option", "format": "flag"}
    :param reset_rev: {"default": 0, "optional": true, "type": "number", "description": "send reset to client if error happens", "format": "flag"}
    :param force_delete_timeout_100ms: {"description": "The maximum time that a session can stay in the system before being delete (number in 100ms)", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "not": "force-delete-timeout", "type": "number"}
    :param half_close_idle_timeout: {"description": "TCP Half Close Idle Timeout (sec), default off (half close idle timeout in second, default off)", "format": "number", "type": "number", "maximum": 120, "minimum": 60, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/tcp/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "tcp"
        self.a10_url="/axapi/v3/slb/template/tcp/{name}"
        self.DeviceProxy = ""
        self.initial_window_size = ""
        self.alive_if_active = ""
        self.qos = ""
        self.name = ""
        self.reset_fwd = ""
        self.half_open_idle_timeout = ""
        self.idle_timeout = ""
        self.force_delete_timeout = ""
        self.lan_fast_ack = ""
        self.insert_client_ip = ""
        self.reset_rev = ""
        self.force_delete_timeout_100ms = ""
        self.half_close_idle_timeout = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Source(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param class_list: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Class-list to match for NAT64", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "source"
        self.DeviceProxy = ""
        self.class_list = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Inside(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "inside"
        self.DeviceProxy = ""
        self.source = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Icmp(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param send_on_user_quota_exceeded: {"default": "admin-filtered", "enum": ["host-unreachable", "admin-filtered", "disable"], "type": "string", "description": "'host-unreachable': Send ICMP destination host unreachable; 'admin-filtered': Send ICMP admin filtered (default); 'disable': Disable ICMP quota exceeded message; ", "format": "enum"}
    :param send_on_port_unavailable: {"default": "disable", "enum": ["host-unreachable", "admin-filtered", "disable"], "type": "string", "description": "'host-unreachable': Send ICMPv6 destination host unreachable; 'admin-filtered': Send ICMPv6 admin filtered; 'disable': Disable ICMPv6 port unavailable message (default); ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "icmp"
        self.DeviceProxy = ""
        self.send_on_user_quota_exceeded = ""
        self.send_on_port_unavailable = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class MssClamp(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param mss_subtract: {"description": "Specify the value to subtract from the TCP MSS (default: 20)", "format": "number", "default": 20, "maximum": 1420, "minimum": 0, "type": "number"}
    :param mss_value: {"description": "The max value allowed for the TCP MSS (default: not configured)", "minimum": 0, "type": "number", "maximum": 1420, "format": "number"}
    :param mss_clamp_type: {"enum": ["fixed", "none", "subtract"], "type": "string", "description": "'fixed': Specify a fixed max value for the TCP MSS; 'none': No TCP MSS clamping; 'subtract': Specify the value to subtract from the TCP MSS (default: 20); ", "format": "enum"}
    :param min: {"description": "Specify the min value allowed for the TCP MSS (Specify the min value allowed for the TCP MSS (default: 476))", "format": "number", "default": 476, "maximum": 1420, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "mss-clamp"
        self.DeviceProxy = ""
        self.mss_subtract = ""
        self.mss_value = ""
        self.mss_clamp_type = ""
        self.A10WW_min = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ResetOnError(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param outbound: {"enum": ["disable"], "type": "string", "description": "'disable': Disable send TCP reset on error; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "reset-on-error"
        self.DeviceProxy = ""
        self.outbound = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Tcp(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "tcp"
        self.DeviceProxy = ""
        self.mss_clamp = {}
        self.reset_on_error = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Global(A10BaseClass):
    
    """Class Description::
    Configure NAT64 parameters.

    Class global supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param user_quota_prefix_length: {"description": "User Quota Prefix Length (Default: 128)", "format": "number", "default": 128, "optional": true, "maximum": 128, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/nat64/global`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "global"
        self.a10_url="/axapi/v3/cgnv6/nat64/global"
        self.DeviceProxy = ""
        self.user_quota_prefix_length = ""
        self.inside = {}
        self.icmp = {}
        self.tcp = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param svrsel_fail: {"description": "Server selection failure", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param default_switching: {"description": "Default switching", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param total_proxy: {"description": "Total proxy conns", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param curr_proxy: {"description": "Current proxy conns", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param target_switching: {"description": "Target ID switching", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param noroute: {"description": "No route failure", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param client_err: {"description": "Client fail", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param sender_switching: {"description": "Sender ID switching", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param server_err: {"description": "Server fail", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param snat_fail: {"description": "Source NAT failure", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param insert_clientip: {"description": "Insert client IP", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.svrsel_fail = ""
        self.default_switching = ""
        self.total_proxy = ""
        self.curr_proxy = ""
        self.target_switching = ""
        self.noroute = ""
        self.client_err = ""
        self.sender_switching = ""
        self.server_err = ""
        self.snat_fail = ""
        self.insert_clientip = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Fix(A10BaseClass):
    
    """Class Description::
    Statistics for the object fix.

    Class fix supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/fix/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "fix"
        self.a10_url="/axapi/v3/slb/fix/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Member(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param member_name: {"platform-specific-default": 1, "type": "string", "description": "Service name", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "member"
        self.DeviceProxy = ""
        self.member_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DisableSiteList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param disable_site: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Site name", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "disable-site-list"
        self.DeviceProxy = ""
        self.disable_site = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ServiceGroup(A10BaseClass):
    
    """Class Description::
    Specify GSLB Service Group.

    Class service-group supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param member: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"member-name": {"platform-specific-default": 1, "type": "string", "description": "Service name", "format": "string"}, "optional": true}}]}
    :param service_group_name: {"description": "Specify Service Group name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param disable_site_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "disable-site": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Site name", "format": "string"}}}]}
    :param disable: {"default": 0, "optional": true, "type": "number", "description": "Disable all members", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/service-group/{service_group_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "service_group_name"]

        self.b_key = "service-group"
        self.a10_url="/axapi/v3/gslb/service-group/{service_group_name}"
        self.DeviceProxy = ""
        self.member = []
        self.service_group_name = ""
        self.disable_site_list = []
        self.disable = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param received_query: {"description": "Number of DNS queries received for the service", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param sent_response: {"description": "Number of DNS replies sent to clients for the service", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param sticky_mode_response: {"description": "Number of DNS replies sent to clients by the ACOS device to keep the clients on the same site. (This statistic applies only if ", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param server_mode_response: {"description": "Number of DNS replies sent to clients by the ACOS device as a DNS server for the service. (This statistic applies only if the D", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param cache_mode_response: {"description": "Number of cached DNS replies sent to clients by the ACOS device for the service. (This statistic applies only if the DNS cache ", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param backup_mode_response: {"description": "help Number of DNS replies sent to clients by the ACOS device in backup mode", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param proxy_mode_response: {"description": "Number of DNS replies sent to clients by the ACOS device as a DNS proxy for the service", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.received_query = ""
        self.sent_response = ""
        self.sticky_mode_response = ""
        self.server_mode_response = ""
        self.cache_mode_response = ""
        self.backup_mode_response = ""
        self.proxy_mode_response = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Service(A10BaseClass):
    
    """Class Description::
    Statistics for the object service.

    Class service supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param dns_ns_record_list: {"minItems": 1, "items": {"type": "dns-ns-record"}, "uniqueItems": true, "array": [{"required": ["ns-name"], "properties": {"stats": {"type": "object", "properties": {"hits": {"description": "Number of times the record has been used", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}}}, "ns-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-a-record/dns-cname-record/{alias-name}/dns-mx-record/{mx-name}/dns-ns-record/{ns-name}"}
    :param dns_cname_record_list: {"minItems": 1, "items": {"type": "dns-cname-record"}, "uniqueItems": true, "array": [{"required": ["alias-name"], "properties": {}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-a-record/dns-cname-record/{alias-name}"}
    :param dns_txt_record_list: {"minItems": 1, "items": {"type": "dns-txt-record"}, "uniqueItems": true, "array": [{"required": ["record-name"], "properties": {"record-name": {"description": "Specify the Object Name for TXT Data", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}, "stats": {"type": "object", "properties": {"hits": {"description": "Number of times the record has been used", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}}}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-a-record/dns-cname-record/{alias-name}/dns-mx-record/{mx-name}/dns-ns-record/{ns-name}/dns-ptr-record/{ptr-name}/dns-srv-record/{srv-name}+{port}/dns-txt-record/{record-name}"}
    :param service_port: {"description": "Port number of the service", "format": "number", "optional": false, "oid": "1001", "maximum": 65534, "minimum": 0, "type": "number"}
    :param dns_mx_record_list: {"minItems": 1, "items": {"type": "dns-mx-record"}, "uniqueItems": true, "array": [{"required": ["mx-name"], "properties": {"stats": {"type": "object", "properties": {"hits": {"description": "Number of times the record has been used", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}}}, "mx-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-a-record/dns-cname-record/{alias-name}/dns-mx-record/{mx-name}"}
    :param dns_record_list: {"minItems": 1, "items": {"type": "dns-record"}, "uniqueItems": true, "array": [{"required": ["type"], "properties": {}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-a-record/dns-cname-record/{alias-name}/dns-mx-record/{mx-name}/dns-ns-record/{ns-name}/dns-ptr-record/{ptr-name}/dns-srv-record/{srv-name}+{port}/dns-txt-record/{record-name}/dns-record/{type}"}
    :param geo_location_list: {"minItems": 1, "items": {"type": "geo-location"}, "uniqueItems": true, "array": [{"required": ["geo-name"], "properties": {}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-a-record/dns-cname-record/{alias-name}/dns-mx-record/{mx-name}/dns-ns-record/{ns-name}/dns-ptr-record/{ptr-name}/dns-srv-record/{srv-name}+{port}/dns-txt-record/{record-name}/dns-record/{type}/geo-location/{geo-name}"}
    :param dns_srv_record_list: {"minItems": 1, "items": {"type": "dns-srv-record"}, "uniqueItems": true, "array": [{"required": ["srv-name", "port"], "properties": {"srv-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}, "stats": {"type": "object", "properties": {"hits": {"description": "Number of times the record has been used", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}}}, "port": {"description": "Specify Port (Port Number)", "format": "number", "optional": false, "oid": "1002", "maximum": 65534, "minimum": 0, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-a-record/dns-cname-record/{alias-name}/dns-mx-record/{mx-name}/dns-ns-record/{ns-name}/dns-ptr-record/{ptr-name}/dns-srv-record/{srv-name}+{port}"}
    :param service_name: {"description": "Specify the service name for the zone, * for wildcard", "format": "string-rlx", "minLength": 1, "oid": "1002", "optional": false, "maxLength": 63, "type": "string"}
    :param dns_ptr_record_list: {"minItems": 1, "items": {"type": "dns-ptr-record"}, "uniqueItems": true, "array": [{"required": ["ptr-name"], "properties": {"ptr-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}, "stats": {"type": "object", "properties": {"hits": {"description": "Number of times the record has been used", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}}}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-a-record/dns-cname-record/{alias-name}/dns-mx-record/{mx-name}/dns-ns-record/{ns-name}/dns-ptr-record/{ptr-name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/zone/{name}/service/{service_port}+{service_name}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "service_port","service_name"]

        self.b_key = "service"
        self.a10_url="/axapi/v3/gslb/zone/{name}/service/{service_port}+{service_name}/stats"
        self.DeviceProxy = ""
        self.dns_a_record = {}
        self.stats = {}
        self.dns_ns_record_list = []
        self.dns_cname_record_list = []
        self.dns_txt_record_list = []
        self.service_port = ""
        self.dns_mx_record_list = []
        self.dns_record_list = []
        self.geo_location_list = []
        self.dns_srv_record_list = []
        self.service_name = ""
        self.dns_ptr_record_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class MacAddress(A10BaseClass):
    
    """Class Description::
    Configure a MAC address.

    Class mac-address supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param static_list: {"minItems": 1, "items": {"type": "static"}, "uniqueItems": true, "array": [{"required": ["mac", "vlan"], "properties": {"dest": {"default": 0, "optional": true, "type": "number", "description": "Trap MAC with this DA to CPU", "format": "flag"}, "mac": {"optional": false, "type": "string", "description": "Configure a Static MAC address", "format": "mac-address"}, "vlan": {"description": "VLAN Id. help-val VLAN Id", "format": "number", "optional": false, "maximum": 4094, "minimum": 1, "type": "number", "$ref": "https://axapi.a10networks.com/axapi/v3/vlan"}, "port": {"optional": true, "type": "number", "description": "Ethernet Port on which the Address is applicable. help-val Port Value", "format": "interface"}}}], "type": "array", "$ref": "https://axapi.a10networks.com/axapi/v3/mac-address/static/{mac}+{vlan}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/mac-address`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "mac-address"
        self.a10_url="/axapi/v3/mac-address"
        self.DeviceProxy = ""
        self.static_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Exec(A10BaseClass):
    
    """Class Description::
    Configuration for EXEC <shell> accounting.

    Class exec supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param accounting_exec_type: {"optional": true, "enum": ["start-stop", "stop-only"], "type": "string", "description": "'start-stop': Record start and stop without waiting; 'stop-only': Record stop when service terminates; ", "format": "enum"}
    :param accounting_exec_method: {"optional": true, "enum": ["tacplus", "radius"], "type": "string", "description": "'tacplus': Use TACACS+ servers for accounting; 'radius': Use radius servers for accounting; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/accounting/exec`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "exec"
        self.a10_url="/axapi/v3/accounting/exec"
        self.DeviceProxy = ""
        self.accounting_exec_type = ""
        self.accounting_exec_method = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Alias(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param alias: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Send CNAME response for this geo-location (Specify a CNAME record)", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "alias"
        self.DeviceProxy = ""
        self.alias = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class GeoLocation(A10BaseClass):
    
    """Class Description::
    Geo location settings.

    Class geo-location supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param forward_type: {"optional": true, "enum": ["both", "query", "response"], "type": "string", "description": "'both': Forward both query and response; 'query': Forward query from this geo-location; 'response': Forward response to this geo-location; ", "format": "enum"}
    :param alias: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"alias": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Send CNAME response for this geo-location (Specify a CNAME record)", "format": "string"}, "optional": true}}]}
    :param action_type: {"optional": true, "enum": ["allow", "drop", "forward", "ignore", "reject"], "type": "string", "description": "'allow': Allow query from this geo-location; 'drop': Drop query from this geo-location; 'forward': Forward packet for this geo-location; 'ignore': Send empty response to this geo-location; 'reject': Send refuse response to this geo-location; ", "format": "enum"}
    :param policy: {"description": "Policy for this geo-location (Specify the policy name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "not": "action", "type": "string"}
    :param action: {"description": "Action for this geo-location", "format": "flag", "default": 0, "optional": true, "not": "policy", "type": "number"}
    :param geo_name: {"description": "Specify the geo-location", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/zone/{name}/service/{service_port}+{service_name}/geo-location/{geo_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "geo_name"]

        self.b_key = "geo-location"
        self.a10_url="/axapi/v3/gslb/zone/{name}/service/{service_port}+{service_name}/geo-location/{geo_name}"
        self.DeviceProxy = ""
        self.forward_type = ""
        self.alias = []
        self.action_type = ""
        self.policy = ""
        self.action = ""
        self.geo_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





__author__ = 'mthompson'
import copy
import inspect
import importlib
import urllib
import json
from urlparse import urlparse
import collections
import re
import os
import keyword


class A10BaseClass(object):
    def __init__(self):
        self.ERROR_MSG = ""

    @classmethod
    def __json__(self, class_object, **kwargs):
        try:
            temp_require = copy.deepcopy(class_object.required)
            del class_object.required
        except:
            pass
        try:
            dp = copy.deepcopy(class_object.DeviceProxy)
            delattr(class_object, "DeviceProxy")
        except:
            pass
        json_object = self.Obj_to_json(class_object.__dict__)

        if 'a10-url' in json_object:
            del json_object['a10-url']
        if "b-key" in json_object:
            del json_object['b-key']

        debug_keys = ["DEBUG-CONNECTION", "DEBUG-Payload", "DEBUG-Response", "DEBUG-URL", "DEBUG-headers"]
        for d_keys in debug_keys:
            try:
                del json_object[d_keys]

            except:
                try:
                    del json_object[class_object.b_key][d_keys]
                except:
                    pass

        try:
            class_object.__setattr__("DeviceProxy", dp)
        except:
            pass
        #(Raunak):json_object is None or empty dictionary return None
        try:
            class_object.__setattr__("required", temp_require)
        except:
            pass
        if not json_object:
            return ''
        elif "sub" in kwargs and kwargs['sub'] == 0:
            return json_object
        else:
            r_object = {}
            r_object[class_object.b_key] = json_object
            return r_object

    @classmethod
    def Obj_to_json(self, obj):
        new_obj = {}
        for k, v in obj.items():
            key = k.replace("_", "-").replace("A10WW_", "").replace(
                "A10WW-", "")
            if "class" in str(type(v)):
                json_obj = self.__json__(v)
                #(Raunak):If the response exists update the new_obj dictionary
                #with the json data
                if json_obj:
                    new_obj.update(json_obj)

            elif (isinstance(v, dict) or
                      isinstance(v, unicode) or
                      isinstance(v, str) or
                      isinstance(v, list)) and len(v) != 0:

                if isinstance(v, list):
                    temp_list = []
                    if len(v) != 0:
                        for i in v:
                            temp_list.append(i.__json__(i, sub=0))

                        new_obj[key] = temp_list

                elif isinstance(v, dict) and len(v) != 0:
                    new_obj[key] = self.Obj_to_json(v)
                elif v is True:
                    new_obj[key] = "1"
                elif v is False:
                    new_obj[key] = "0"
                elif v is not None:
                    if len(v) != 0:
                        new_obj[key] = v
            elif isinstance(v, int):
                new_obj[key] = v

            # If it's an attribute and it's value is None, use None
            elif v is None:
                new_obj[key] = v

        return new_obj

    '''
    Converts from Unicode
    '''

    def convert(self, data):
        if isinstance(data, basestring):
            return str(data)
        elif isinstance(data, collections.Mapping):
            return dict(map(self.convert, data.iteritems()))
        elif isinstance(data, collections.Iterable):
            return type(data)(map(self.convert, data))
        else:
            return data

    """
    GET THE PARENT KEY ASS NEEDED
    """

    def find_key(self, d, key):
        for k, v in d.items():
            if isinstance(v, dict):
                p = self.find_key(v, key)
                if p:
                    return [k] + p
            elif v == key:
                return [k]

    def _format_key_name_for_module_lookup(self, key, lambda_expression):
        if key.startswith('A10WW_'):
            return lambda_expression(key)
        else:
            return lambda_expression(key).title()


    def _search_for_child_object_module(self, caller, sub_class):
        try:
            if caller.__name__.endswith('_oper'):
                module_name = caller.__name__.replace('_oper', '')
                caller_name = importlib.import_module(module_name + "_" + sub_class.lower() + "_oper")
            elif caller.__name__.endswith('_stats'):
                module_name = caller.__name__.replace('_stats', '')
                caller_name = importlib.import_module(module_name + "_" + sub_class.lower() + "_stats")
            else:
                caller_name = importlib.import_module(caller.__name__ + "_" + sub_class.lower())
        except:
            caller_name = importlib.import_module(caller.__name__)

        return caller_name

    def _search_for_child_class_inside_module(self, child_node_name, caller_name, DeviceProxy):
        k = child_node_name
        sub_class = ''.join(
            x for x in k.replace("-list", "", 1).replace("-", "_").title() if
            not x.isspace())
        try:
            obj_class = getattr(caller_name, sub_class)(DeviceProxy=DeviceProxy)
        except:
            try:
                sub_class = ''.join(
                    x for x in k.replace("-", " ").replace("-list", "", 1).title()
                    if not x.isspace())
                obj_class = getattr(caller_name, sub_class)(DeviceProxy=DeviceProxy)
            except:
                try:
                    sub_class = ''.join(x for x in
                                        k.replace("-", "").replace("list", "").replace("list",
                                                                                       "").title()
                                        if not x.isspace())
                    obj_class = getattr(caller_name, sub_class)(DeviceProxy=DeviceProxy)
                except:
                    try:
                        sub_class = ''.join(x for x in
                                            k.replace("-", "_").replace("list", "").replace("list",
                                                                                            "").title()
                                            if not x.isspace())
                        obj_class = getattr(caller_name, sub_class)(DeviceProxy=DeviceProxy)
                    except:
                        #(RAUNAK):Added one more check for the VLAN tagged_ethernet_list like cases
                        #Would check for the class with the name TaggedEthernet
                        try:
                            sub_class = ''.join(x for x in
                                                k.replace("-", "_").replace("list", "").replace(
                                                    "list",
                                                    "").title().replace('_', '')
                                                if not x.isspace())
                            obj_class = getattr(caller_name, sub_class)(DeviceProxy=DeviceProxy)
                        except:
                            #(Raunak):Added this for ClassList
                            try:
                                sub_class = ''.join(x for x in
                                                    k.replace("-list", "").title() + 'List'
                                                    if not x.isspace())
                                obj_class = getattr(caller_name, sub_class)(DeviceProxy=DeviceProxy)
                            except:
                                pass

        return obj_class


    def Factory(self, DeviceProxy, obj, name, parent=''):

        obj = self.convert(obj)

        # for i in obj:
        #     self.default_object_key = i

        if parent:
            caller = inspect.getmodule(parent)
        else:
            caller = inspect.getmodule(self)
        top_node_obj_list = []
        for list_name_key, list_name_value in obj.items():
            if list_name_key == 'class-list-list':
                class_object = 'ClassList'
                break
            else:
                class_object = ''.join(
                    x for x in list_name_key.replace("-", " ").replace(
                        "list", "").title() if not x.isspace())
                if not class_object:
                    class_object = ''.join(
                        x for x in list_name_key.replace("-", " ").title() if not x.isspace())

                class_object = kwbl().kwbl(class_object)
            try:
                caller = importlib.import_module(caller.__name__)
                new_class = getattr(caller, class_object)(DeviceProxy=DeviceProxy)

            except:
                try:
                    caller = importlib.import_module(caller.__name__)
                    new_class = getattr(caller, class_object + 'List')(DeviceProxy=DeviceProxy)
                except:
                    try:
                        caller = importlib.import_module(caller.__name__ + "_" + list_name_key.lower())
                        new_class = getattr(caller, class_object)(DeviceProxy=DeviceProxy)

                    except:

                        try:
                            caller = importlib.import_module(
                                caller.__name__ + "_" + list_name_key.replace('-', '_').lower())
                            new_class = getattr(caller, class_object)(DeviceProxy=DeviceProxy)

                        except:
                            try:
                                temp_name = list_name_key.split("-")
                                test_module = temp_name[0]
                                caller = importlib.import_module(caller.__name__ + "_" + test_module.lower())
                                new_class = getattr(caller, class_object)(DeviceProxy=DeviceProxy)
                            except:
                                try:
                                    caller = importlib.import_module(
                                        caller.__name__ + "_" + parent.lower() + "_" + list_name_key.lower())
                                    new_class = getattr(caller, class_object)(DeviceProxy=DeviceProxy)

                                except:
                                    try:
                                        caller = importlib.import_module(caller.__name__ + "_" + parent.lower())
                                        new_class = getattr(caller, class_object)(DeviceProxy=DeviceProxy)

                                    except Exception as e:
                                        try:
                                            # try to import class from all sibling modules
                                            found_in_sibling = False
                                            for module in os.listdir(os.path.dirname(caller.__file__)):
                                                if module.endswith("py") and module != "__init__.py":
                                                    try:
                                                        class_name = ''.join(
                                                            x for x in list_name_key.split("-").pop().title() if
                                                            not x.isspace())
                                                        caller_sibling_modules = importlib.import_module(
                                                            "." + module.replace(".py", ""), caller.__package__)
                                                        new_class = getattr(caller_sibling_modules, class_name)(
                                                            DeviceProxy=DeviceProxy)
                                                        found_in_sibling = True
                                                        break
                                                    except:
                                                        try:
                                                            class_name = ''.join(
                                                                x for x in list_name_key.replace("-", " ").title() if
                                                                not x.isspace())
                                                            caller_sibling_modules = importlib.import_module(
                                                                "." + module.replace(".py", ""), caller.__package__)
                                                            new_class = getattr(caller_sibling_modules, class_name)(
                                                                DeviceProxy=DeviceProxy)
                                                            found_in_sibling = True
                                                            break
                                                        except:
                                                            pass
                                                        pass
                                            if found_in_sibling is False:
                                                raise e
                                        except:
                                            return obj

            # class_object
            if isinstance(list_name_value, list):
                for list_obj in list_name_value:
                    sdk_obj = copy.deepcopy(new_class)

                    for k, v in list_obj.items():
                        k = kwbl().kwbl(k)
                        new_obj_name = k.replace("-list", "", 1).replace("-", "_")
                        if new_obj_name[len(new_obj_name) - 1] == "_":
                            new_obj_name = ''.join(
                                x for x in k.replace("-", " ").replace("-list", "", 1).title() if
                                not x.isspace())

                        if isinstance(v, list):
                            obj_name_list = []
                            caller_name = self._search_for_child_object_module(caller, new_obj_name)
                            for keys in v:
                                obj_class = self._search_for_child_class_inside_module(k, caller_name, DeviceProxy)
                                # obj_class = getattr(caller_name, new_obj_name)(DeviceProxy=DeviceProxy)
                                for v_key, v_val in keys.items():
                                    v_key = kwbl().kwbl(v_key)
                                    if v_key == "a10-url":
                                        temp_v = urlparse(v_val)
                                        v_val = temp_v.path
                                    obj_class.__setattr__(v_key.replace("-", "_"), v_val)
                                obj_name_list.append(obj_class)
                            sdk_obj.__setattr__(k.replace("-", "_"), obj_name_list)
                        elif isinstance(v, dict):
                            sdk_obj.__setattr__(k.replace("-", "_"),
                                                  (sdk_obj.Factory(DeviceProxy, {k: v}, k, sdk_obj)))
                        else:
                            sdk_obj.__setattr__(new_obj_name.replace("-", "_"), v)
                    top_node_obj_list.append(copy.deepcopy(sdk_obj))
            else:
                with_native_list_in_name = ['access-list', 'ip-map-list', 'acl-id-list-list', 'acl-name-list-list',
                                            'lsn-rule-list',
                                            'inside-src-permit-list', 'nat-ip-list', 'inside-ip-list', 'ipv4-list']
                for k, v in list_name_value.items():
                    k = kwbl().kwbl(k)
                    if k == "a10-url":
                        temp_v = urlparse(v)
                        v = temp_v.path

                    if k in with_native_list_in_name:
                        new_obj_name = with_native_list_in_name[with_native_list_in_name.index(k)].replace('-', '_')
                        # Bug 191464  Mike Thompson detecting type vs name.
                    elif not isinstance(v, list):
                        new_obj_name = k.replace("-", "_")
                    else:
                        new_obj_name = k.replace("-list", "", 1).replace("-", "_") if k.endswith('list') else k.replace(
                            "-", "_")

                    if isinstance(v, list):
                        obj_name_list = []
                        caller_name = self._search_for_child_object_module(caller, new_obj_name)
                        for keys in v:
                            obj_class = self._search_for_child_class_inside_module(k, caller_name, DeviceProxy)
                            for v_key, v_val in keys.items():
                                v_key = kwbl().kwbl(v_key)
                                if v_key == "a10-url":
                                    temp_v = urlparse(v_val)
                                    v_val = temp_v.path
                                elif isinstance(v_val, dict):
                                    obj_class.__setattr__(v_key.replace("-", "_"), (
                                        obj_class.Factory(DeviceProxy, {v_key: v_val}, v_key, obj_class)))
                                    continue
                                elif isinstance(v_val, list):
                                    sub_obj = obj_class.Factory(DeviceProxy, {v_key: v_val}, v_key, obj_class)
                                    sub_obj_list = getattr(obj_class, v_key, [])
                                    if isinstance(sub_obj, list):
                                        sub_obj_list = sub_obj_list + sub_obj
                                    else:
                                        sub_obj_list.append(sub_obj)
                                    setattr(obj_class, v_key.replace("-", "_"), sub_obj_list)
                                    continue

                                obj_class.__setattr__(v_key.replace("-", "_"), v_val)

                            obj_name_list.append(obj_class)

                        new_class.__setattr__(k.replace("-", "_"), copy.deepcopy(obj_name_list))

                    elif isinstance(v, dict):
                        new_class.__setattr__(new_obj_name, (new_class.Factory(DeviceProxy, {k: v}, k, new_class)))
                    else:
                        new_class.__setattr__(new_obj_name, v)
            try:
                if top_node_obj_list and len(top_node_obj_list) > 0:
                    return top_node_obj_list
                else:
                    return new_class
            except:
                pass

    def depth_finder(self, d, depth=0):

        if isinstance(d, list):
            if not isinstance(d, dict) or not d or not isinstance(d, list):
                return depth
            elif isinstance(d, dict):
                depth

        if not isinstance(d, dict) or not d:
            return depth

        return max(self.depth_finder(v, depth + 1) for k, v in d.iteritems())


    def get(self, query_params=None, **kwargs):
        if len(kwargs) > 0:
            self.a10_url_update(**kwargs)
        else:
            self.a10_url_parent()
        request = self.DeviceProxy.GET(self, query_params)
        try:
            request = json.loads(request, encoding='utf-8')
        except:
            if request is None:
                self.ERROR_MSG = "None Returned"
                return self
            elif 'response' in request and request['response']['err']:
                self.ERROR_MSG = request
                return self
            elif "Session Timeout" in request:
                self.ERROR_MSG = request
                return self

        if request is None:
            self.ERROR_MSG = "None Returned"
            return self
        elif not isinstance(request, dict):
            self.ERROR_MSG = 'Invalid Response'
            return self
        # elif 'response' in request and request['response']['err']:
        elif 'response' in request and request.get('response').get('err', None):
            self.ERROR_MSG = request
            return self
        elif "Session Timeout" in request:
            self.ERROR_MSG = request
            return self

        if len(kwargs) > 0:
            temp_object = self.Factory(self.DeviceProxy, request, name=1)
            try:
                temp_object.__setattr__("_HTTP_RESPONSE", self._HTTP_RESPONSE)
                temp_object.__setattr__("DEBUG_CONNECTION", self.DEBUG_CONNECTION)
                temp_object.__setattr__("DEBUG_Payload", self.DEBUG_Payload)
                temp_object.__setattr__("DEBUG_Response", self.DEBUG_Response)
                temp_object.__setattr__("DEBUG_URL", self.DEBUG_URL)
                temp_object.__setattr__("DEBUG_headers", self.DEBUG_headers)
            except Exception:
                pass
            return temp_object
        else:
            r_list = []
            for k, v in request.items():
                if "List" in k:
                    wrapper_key = k.replace("-list", "", 1)

                elif "list" in k:
                    wrapper_key = k.replace("-list", "", 1)
                else:
                    wrapper_key = k
                if wrapper_key[len(wrapper_key) - 1] == "_":
                    wrapper_key = wrapper_key[:len(wrapper_key) - 1]
                if isinstance(v, list):
                    for i in v:
                        new_object = self.Factory(self.DeviceProxy, {wrapper_key: i}, name=0, parent="")
                        new_object.__setattr__("_HTTP_RESPONSE", self._HTTP_RESPONSE)
                        new_object.__setattr__("DEBUG_CONNECTION", self.DEBUG_CONNECTION)
                        new_object.__setattr__("DEBUG_Payload", self.DEBUG_Payload)
                        new_object.__setattr__("DEBUG_Response", self.DEBUG_Response)
                        new_object.__setattr__("DEBUG_URL", self.DEBUG_URL)
                        new_object.__setattr__("DEBUG_headers", self.DEBUG_headers)
                        r_list.append(new_object)
                else:
                    try:
                        new_object = self.Factory(self.DeviceProxy, request, name=1)
                        new_object.__setattr__("_HTTP_RESPONSE", self._HTTP_RESPONSE)
                        new_object.__setattr__("DEBUG_CONNECTION", self.DEBUG_CONNECTION)
                        new_object.__setattr__("DEBUG_Payload", self.DEBUG_Payload)
                        new_object.__setattr__("DEBUG_Response", self.DEBUG_Response)
                        new_object.__setattr__("DEBUG_URL", self.DEBUG_URL)
                        new_object.__setattr__("DEBUG_headers", self.DEBUG_headers)
                    except:
                        pass
                    return new_object

        return r_list

    def create(self, **kwargs):
        o_url = self.a10_url
        if len(kwargs) > 0:
            self.a10_url_update(**kwargs)
        else:
            self.a10_url_parent()
        response = self.response_handler(self.DeviceProxy.POST(self))
        self.a10_url = o_url
        return response

    def update(self, **kwargs):
        o_url = self.a10_url
        if len(kwargs) > 0:
            self.a10_url_update(**kwargs)
        else:
            self.a10_url_parent()

        response = self.response_handler(self.DeviceProxy.POST(self))
        self.a10_url = o_url
        return response

    def replace(self, **kwargs):
        o_url = self.a10_url
        if len(kwargs) > 0:
            self.a10_url_update(**kwargs)
        else:
            self.a10_url_parent()
        response = self.response_handler(self.DeviceProxy.PUT(self))
        self.a10_url = o_url
        return response

    def replace_all(self, obj_list):
        o_url = self.a10_url
        self.a10_url_parent()
        response = self.response_handler(self.DeviceProxy.PUT_ALL(self, obj_list))
        self.a10_url = o_url
        return response

    def create_all(self, obj_list):
        o_url = self.a10_url
        self.a10_url_parent()
        response = self.response_handler(self.DeviceProxy.POST_ALL(self, obj_list))
        self.a10_url = o_url
        return response


    def delete(self, **kwargs):
        o_url = self.a10_url
        if len(kwargs) > 0:
            self.a10_url_update(**kwargs)
        else:
            self.a10_url_parent()
        response = self.response_handler(self.DeviceProxy.DELETE(self))
        self.a10_url = o_url
        return response


    def a10_url_update(self, **kwargs):
        temp_url = self.a10_url
        try:
            for key, value in kwargs.items():
                if isinstance(value, tuple) or isinstance(value, list):
                    for v in value:
                        v = urllib.quote_plus(str(v).replace(' ', "%20"))
                        v = v.replace('%2520', '%20')
                        self.a10_url = self.a10_url.replace('{%s}' % key, v, 1)
                else:
                    #Python converts white spaces to +
                    #Modifying this behavior to use %20 encoding instead
                    value = urllib.quote_plus(str(value).replace(' ', '%20'))
                    value = value.replace('%2520', '%20')
                    self.a10_url = self.a10_url.replace('{%s}' % key, value)
            #Removing any unresolved keys and removing the +
            while(len(kwargs)> 0 and '{' in self.a10_url):
                try:
                    start_index = self.a10_url.index('{')
                    end_index = self.a10_url.index('}')
                    self.a10_url = self.a10_url.replace(self.a10_url[start_index:end_index+1], '')
                except ValueError as e:
                    print 'Substring not found', e
                    break
            self.a10_url = self.a10_url.replace('+/', '/')
            self.a10_url = self.a10_url.replace('/+', '/')
            self.a10_url = self.a10_url.replace('+', '', -1) if self.a10_url.endswith('+') else self.a10_url
            if '{' in self.a10_url:
                self.a10_url_parent(**kwargs)
        except:
            try:
                self.a10_url_parent(**kwargs)
            except:
                self.a10_url = temp_url


    def a10_url_override(self, url):
        self.a10_url = url

    #TODO: Need to build a more intelligent handler.


    def a10_url_parent(self, **kwargs):
        if "{" in self.a10_url:
            p_list = self.a10_url.split("/")

            if self.a10_url.endswith('oper'):
                temp = self.a10_url.replace(p_list[(len(p_list) - 2)] + '/', "")
                self.a10_url = temp
            elif self.a10_url.endswith('stats'):
                temp = self.a10_url.replace(p_list[(len(p_list) - 2)] + '/', "")
                self.a10_url = temp
            else:
                temp = self.a10_url.replace(p_list[(len(p_list) - 1)], "")
                self.a10_url = temp[0:len(temp) - 1]
        if len(kwargs) > 0:
            try:
                self.a10_url = self.a10_url.format(**kwargs)
            except:
                pass

    def get_stats(self, url="", Filters={}, **kwargs):
        if url == "":
            o_url = self.a10_url
        else:
            o_url = self.a10_url
            self.a10_url = url

        if len(kwargs) > 0:
            try:
                self.a10_url = self.a10_url.format(**kwargs)

            except:
                pass
            """
            If you are utilizing the stats class &| you want to get stats from a parent.
            """
        if "{" in self.a10_url:
            self.a10_url = re.match(r'^(/.+?/{)', self.a10_url).group(0).replace("/{", "")

        if "stats" not in self.a10_url:
            self.a10_url = self.a10_url + "/stats"

        if len(Filters) > 0:
            query = urllib.urlencode(**Filters)
            endpoint = self.a10_url + "?" + query
            temp_url = self.a10_url
            self.a10_url = endpoint
        response = self.response_handler(self.DeviceProxy.GET(self), False)
        self.a10_url = o_url
        return response


    def del_stats(self, url="", Filters={}, **kwargs):
        if url == "":
            o_url = self.a10_url
        else:
            o_url = self.a10_url
            self.a10_url = url

        if len(kwargs) > 0:
            try:
                self.a10_url = self.a10_url.format(**kwargs)

            except:
                pass
            """
            If you are utilizing the stats class &| you want to get stats from a parent.
            """
        if "{" in self.a10_url:
            self.a10_url = re.match(r'^(/.+?/{)', self.a10_url).group(0).replace("/{", "")

        if "stats" not in self.a10_url:
            self.a10_url = self.a10_url + "/stats"

        if len(Filters) > 0:
            query = urllib.urlencode(**Filters)
            endpoint = self.a10_url + "?" + query
            temp_url = self.a10_url
            self.a10_url = endpoint
        response = self.response_handler(self.DeviceProxy.DELETE(self), False)
        self.a10_url = o_url
        return response

    def get_oper(self, url="", Filters={}, **kwargs):
        if url == "":
            o_url = self.a10_url
        else:
            o_url = self.a10_url
            self.a10_url = url

        if len(kwargs) > 0:
            try:
                self.a10_url = self.a10_url.format(**kwargs)
            except:
                pass
            """
            If you are utilizing the stats class &| you want to get stats from a parent.
            """
        if "{" in self.a10_url:
            self.a10_url = re.match(r'^(/.+?/{)', self.a10_url).group(0).replace("/{", "")

        if "oper" not in self.a10_url:
            self.a10_url = self.a10_url + "/oper"
        if len(Filters) > 0:
            query = urllib.urlencode(**Filters)
            endpoint = self.a10_url + "?" + query
            temp_url = self.a10_url
            self.a10_url = endpoint
        response = self.response_handler(self.DeviceProxy.GET(self), False)
        self.a10_url = o_url
        return response

    def response_handler(self, response, r_obj=True):
        try:
            response = json.loads(response, encoding='utf-8')
        except:
            pass
        try:
            if response is None:
                self.ERROR_MSG = "None Returned"
                return self
            elif 'response' in response:
                if "err" in response['response']:
                    self.ERROR_MSG = response
                    return self
                elif "status" in response['response']:
                    if response['response']['status'] == "OK":
                        return self
            elif "Session Timeout" in response:
                self.ERROR_MSG = response
                return self
            else:
                if r_obj == True:
                    self.ERROR_MSG = ""
                    return self
                else:
                    return response
        except:
            self.ERROR_MSG = response
            return self


    #Helper method for single file upload
    def file_upload(self, filename=None, file_handle=None, file_obj=None):
        u_fields = [("json", {self.b_key:{"file":filename,
                                          "file-handle":file_handle,
                                          "action":'import'}})]

        u_files = [(filename, file_handle, file_obj)]

        return self.files_upload(u_fields, u_files)

    #Added to address file_upload and downloads
    def files_upload(self, fields=[], files=[]):

        '''
        API only supports one file being uploaded at a time.
        :params fields: [("json", {self.b_key:{"file":filename,
                                             "file-handle":file_handle,
                                             "action":action}})]
        :params files:[("file", filename, file_obj)]
        '''

        self.fields = fields
        self.files = files
        return self.DeviceProxy.post_multipart(self)

    def file_download(self, name=None):
        '''
        This bypasses the factory so the raw file content can be returned.
        '''

        self.a10_url = self.a10_url + "/" + name
        return self.DeviceProxy.multi_part_get(self)


    def file_replace(self, filename=None, file_handle=None, file_obj=None):
        u_fields = [("json", {self.b_key:{"file":filename,
                                          "file-handle":file_handle,
                                          "action":'import'}})]

        u_files = [(filename, file_handle, file_obj)]

        return self.files_upload(u_fields, u_files)

    def file_delete(self, name=None):
        self.a10_url = self.a10_url + "/" + name
        return self.DeviceProxy.DELETE(self)


class kwbl():
    def kwbl(self, word, key=0):
        # if word in dir(__builtins__) or 'copy' in word:
        # (echou): Replace to workaround Django vs Python __builtins__
        # (raunak): Use the Python builtins to have a consistent behavior with the sdk_generator
        python_built_in = ['bytearray', 'IndexError', 'all', 'help', 'vars', 'SyntaxError', 'unicode',
                           'UnicodeDecodeError', 'memoryview',
                           'isinstance', 'copyright', 'NameError', 'BytesWarning', 'dict', 'IOError', 'oct', 'bin',
                           'SystemExit',
                           'StandardError', 'format', 'TabError', 'sorted', 'False', 'RuntimeWarning', 'list', 'iter',
                           'reload',
                           'Warning', '__package__', 'round', 'dir', 'cmp', 'set', 'bytes', 'UnicodeTranslateError',
                           'intern',
                           'issubclass', 'Ellipsis', 'EOFError', 'locals', 'BufferError', 'slice', 'FloatingPointError',
                           'sum', 'getattr',
                           'abs', 'exit', 'print', 'True', 'FutureWarning', 'ImportWarning', 'None', 'hash',
                           'ReferenceError', 'len',
                           'credits', 'frozenset', '__name__', 'ord', 'super', '_', 'TypeError', 'license',
                           'KeyboardInterrupt',
                           'UserWarning', 'filter', 'range', 'staticmethod', 'SystemError', 'BaseException', 'pow',
                           'RuntimeError',
                           'float', 'GeneratorExit', 'StopIteration', 'globals', 'divmod', 'enumerate', 'apply',
                           'LookupError', 'open',
                           'quit', 'basestring', 'UnicodeError', 'zip', 'hex', 'long', 'next', 'ImportError', 'chr',
                           '__import__', 'type',
                           'Exception', 'tuple', 'reduce', 'reversed', 'UnicodeEncodeError', 'input', 'hasattr',
                           'delattr', 'setattr',
                           'raw_input', 'PendingDeprecationWarning', 'compile', 'ArithmeticError', 'str', 'property',
                           'MemoryError',
                           'int', 'xrange', 'KeyError', 'coerce', 'SyntaxWarning', 'file', 'EnvironmentError', 'unichr',
                           'id', 'OSError',
                           'DeprecationWarning', 'min', 'UnicodeWarning', 'execfile', 'any', 'complex', 'bool',
                           'ValueError',
                           'NotImplemented', 'map', 'buffer', 'max', 'object', 'repr', 'callable', 'ZeroDivisionError',
                           'eval',
                           '__debug__', 'IndentationError', 'AssertionError', 'classmethod', 'UnboundLocalError',
                           'NotImplementedError',
                           'AttributeError', 'OverflowError']
        if word in dir(__builtins__) or 'copy' in word or word in python_built_in:
            if key == 0:
                return "A10WW_" + word
            else:
                return "A10_" + word
        # (echou): Comment out sys.modules check per discussionw with mthompson and raunaka
        # elif word in sys.modules.keys():
        #     if key == 0:
        #         return "A10WW_" + word
        #     else:
        #         return "A10_" + word
        elif word in keyword.kwlist:
            if key == 0:
                return "A10WW_" + word
            else:
                return "A10_" + word
        elif re.search(r'^[0-9]', word):
            if key == 0:
                return "A10WW_" + word
            else:
                return "A10_" + word
        else:
            return word



from a10sdk.common.A10BaseClass import A10BaseClass


class TcpProxy(A10BaseClass):
    
    """Class Description::
    TCP Proxy.

    Class tcp-proxy supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param qos: {"description": "QOS level (number)", "format": "number", "type": "number", "maximum": 63, "minimum": 1, "optional": true}
    :param init_cwnd: {"description": "The initial congestion control window size (packets), default is 4 (number)", "format": "number", "default": 4, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}
    :param idle_timeout: {"description": "Idle Timeout (sec), default is 600 (number)", "format": "number", "default": 600, "optional": true, "maximum": 2097151, "minimum": 1, "type": "number"}
    :param fin_timeout: {"description": "FIN timeout (sec), default is 5 (number)", "format": "number", "default": 5, "optional": true, "maximum": 60, "minimum": 1, "type": "number"}
    :param half_open_idle_timeout: {"description": "TCP Half Open Idle Timeout (sec), default is off (number)", "format": "number", "type": "number", "maximum": 60, "minimum": 1, "optional": true}
    :param reno: {"default": 0, "optional": true, "type": "number", "description": "Enable Reno Congestion Control Algorithm", "format": "flag"}
    :param timewait: {"description": "Timewait Threshold (sec), default 5 (number)", "format": "number", "default": 5, "optional": true, "maximum": 60, "minimum": 1, "type": "number"}
    :param dynamic_buffer_allocation: {"default": 0, "optional": true, "type": "number", "description": "Optimally adjust the transmit and receive buffer sizes of TCP proxy while keeping their sum constant", "format": "flag"}
    :param alive_if_active: {"default": 0, "optional": true, "type": "number", "description": "keep connection alive if active traffic", "format": "flag"}
    :param mss: {"description": "Responding MSS to use if client MSS is large, default is off (number)", "format": "number", "default": 1460, "optional": true, "maximum": 4312, "minimum": 128, "type": "number"}
    :param keepalive_interval: {"description": "Interval between keepalive probes (sec), default is off (number)", "format": "number", "type": "number", "maximum": 12000, "minimum": 60, "optional": true}
    :param retransmit_retries: {"description": "Number of Retries for Retransmit, default is 3", "format": "number", "default": 3, "optional": true, "maximum": 20, "minimum": 1, "type": "number"}
    :param insert_client_ip: {"default": 0, "optional": true, "type": "number", "description": "Insert client ip into TCP option", "format": "flag"}
    :param nagle: {"default": 0, "optional": true, "type": "number", "description": "Enable Nagle Algorithm", "format": "flag"}
    :param force_delete_timeout_100ms: {"description": "The maximum time that a session can stay in the system before being deleted, default is off (number in 100ms)", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "not": "force-delete-timeout", "type": "number"}
    :param initial_window_size: {"description": "Set the initial window size, default is off (number)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param keepalive_probes: {"description": "Number of keepalive probes sent, default is off", "format": "number", "type": "number", "maximum": 10, "minimum": 2, "optional": true}
    :param ack_aggressiveness: {"description": "'low': Delayed ACK; 'medium': Delayed ACK, with ACK on each packet with PUSH flag; 'high': ACK on each packet; ", "format": "enum", "default": "low", "type": "string", "enum": ["low", "medium", "high"], "optional": true}
    :param backend_wscale: {"description": "The TCP window scale used for the server side, default is off (number)", "format": "number", "type": "number", "maximum": 14, "minimum": 1, "optional": true}
    :param reset_rev: {"default": 0, "optional": true, "type": "number", "description": "send reset to client if error happens", "format": "flag"}
    :param receive_buffer: {"description": "TCP Receive Buffer (default 50k) (number)", "format": "number", "default": 51200, "optional": true, "maximum": 2147483647, "minimum": 1, "type": "number"}
    :param transmit_buffer: {"description": "TCP Transmit Buffer (default 50k) (number)", "format": "number", "default": 51200, "optional": true, "maximum": 2147483647, "minimum": 1, "type": "number"}
    :param name: {"description": "TCP Proxy Template Name", "format": "string", "default": "default", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param reset_fwd: {"default": 0, "optional": true, "type": "number", "description": "send reset to server if error happens", "format": "flag"}
    :param syn_retries: {"description": "SYN Retry Numbers, default is 5", "format": "number", "default": 5, "optional": true, "maximum": 20, "minimum": 1, "type": "number"}
    :param force_delete_timeout: {"description": "The maximum time that a session can stay in the system before being deleted, default is off (number (second))", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "not": "force-delete-timeout-100ms", "type": "number"}
    :param half_close_idle_timeout: {"description": "TCP Half Close Idle Timeout (sec), default is off (number)", "format": "number", "type": "number", "maximum": 120, "minimum": 60, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/tcp-proxy/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "tcp-proxy"
        self.a10_url="/axapi/v3/slb/template/tcp-proxy/{name}"
        self.DeviceProxy = ""
        self.qos = ""
        self.init_cwnd = ""
        self.idle_timeout = ""
        self.fin_timeout = ""
        self.half_open_idle_timeout = ""
        self.reno = ""
        self.timewait = ""
        self.dynamic_buffer_allocation = ""
        self.alive_if_active = ""
        self.mss = ""
        self.keepalive_interval = ""
        self.retransmit_retries = ""
        self.insert_client_ip = ""
        self.nagle = ""
        self.force_delete_timeout_100ms = ""
        self.initial_window_size = ""
        self.keepalive_probes = ""
        self.ack_aggressiveness = ""
        self.backend_wscale = ""
        self.reset_rev = ""
        self.receive_buffer = ""
        self.transmit_buffer = ""
        self.name = ""
        self.reset_fwd = ""
        self.syn_retries = ""
        self.force_delete_timeout = ""
        self.half_close_idle_timeout = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param inbound_ipv6_fragment_received: {"description": "Inbound IPv6 fragment packets received", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param inbound_ipv4_unreachable: {"description": "Inbound IPv4 destination unreachable", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param icmp_to_icmpv6: {"description": "ICMP to ICMPv6", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param outbound_ipv4_fragment_received: {"description": "Outbound IPv4 fragment packets received", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param outbound_ipv4_received: {"description": "Outbound IPv4 packets received", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param outbound_ipv6_fragmented: {"description": "Outbound IPv6 packets fragmented", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param ha_standby: {"description": "HA is standby", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "8"}
    :param packet_too_big: {"description": "Packet too big", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param inbound_ipv6_received: {"description": "Inbound IPv6 packets received", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param fragment_error: {"description": "Fragment processing errors", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param inbound_ipv6_drop: {"description": "Inbound IPv6 packets dropped", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param icmpv6_to_icmp: {"description": "ICMPv6 to ICMP", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param outbound_ipv4_drop: {"description": "Outbound IPv4 packets dropped", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param icmpv6_to_icmp_error: {"description": "ICMPv6 to ICMP errors", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param inbound_ipv4_fragmented: {"description": "Inbound IPv4 packets fragmented", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param outbound_ipv6_unreachable: {"description": "Outbound IPv6 destination unreachable", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param other_error: {"description": "Other errors", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "8"}
    :param icmp_to_icmpv6_error: {"description": "ICMP to ICMPv6 errors", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.inbound_ipv6_fragment_received = ""
        self.inbound_ipv4_unreachable = ""
        self.icmp_to_icmpv6 = ""
        self.outbound_ipv4_fragment_received = ""
        self.outbound_ipv4_received = ""
        self.outbound_ipv6_fragmented = ""
        self.ha_standby = ""
        self.packet_too_big = ""
        self.inbound_ipv6_received = ""
        self.fragment_error = ""
        self.inbound_ipv6_drop = ""
        self.icmpv6_to_icmp = ""
        self.outbound_ipv4_drop = ""
        self.icmpv6_to_icmp_error = ""
        self.inbound_ipv4_fragmented = ""
        self.outbound_ipv6_unreachable = ""
        self.other_error = ""
        self.icmp_to_icmpv6_error = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Global(A10BaseClass):
    
    """Class Description::
    Statistics for the object global.

    Class global supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/nat46-stateless/global/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "global"
        self.a10_url="/axapi/v3/cgnv6/nat46-stateless/global/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class IfList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param IF_Status: {"enum": ["pristine", "owned"], "type": "string", "format": "enum"}
    :param IF_Num: {"type": "number", "format": "number"}
    :param IF_Type: {"enum": ["ethernet"], "type": "string", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "if-list"
        self.DeviceProxy = ""
        self.IF_Status = ""
        self.IF_Num = ""
        self.IF_Type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param if_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"IF-Status": {"enum": ["pristine", "owned"], "type": "string", "format": "enum"}, "IF-Num": {"type": "number", "format": "number"}, "IF-Type": {"enum": ["ethernet"], "type": "string", "format": "enum"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.if_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class EthAvailableList(A10BaseClass):
    
    """Class Description::
    Operational Status for the object eth-available-list.

    Class eth-available-list supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/eth-available-list/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "eth-available-list"
        self.a10_url="/axapi/v3/interface/eth-available-list/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Partition(A10BaseClass):
    
    """Class Description::
    Create/unload a Network partition.

    Class partition supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param partition_name: {"description": "Object partition name", "format": "string", "minLength": 1, "optional": false, "maxLength": 14, "type": "string"}
    :param application_type: {"optional": true, "enum": ["adc", "cgnv6"], "type": "string", "description": "'adc': Application type ADC; 'cgnv6': Application type CGNv6; ", "format": "enum"}
    :param id: {"description": "Specify unique Partition id", "format": "number", "optional": true, "maximum": 127, "minimum": 1, "modify-not-allowed": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/partition/{partition_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "partition_name"]

        self.b_key = "partition"
        self.a10_url="/axapi/v3/partition/{partition_name}"
        self.DeviceProxy = ""
        self.partition_name = ""
        self.application_type = ""
        self.A10WW_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class HttpsKerberosKdc(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param https_kerberos_portv6: {"description": "Specify the kdc port", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param https_kerberos_port: {"description": "Specify the kdc port", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param https_kerberos_hostip: {"description": "Kdc's hostname or IP address", "format": "host", "minLength": 1, "maxLength": 31, "not": "https-kerberos-hostipv6", "type": "string"}
    :param https_kerberos_hostipv6: {"not": "https-kerberos-hostip", "type": "string", "description": "Server's IPV6 address", "format": "ipv6-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "https-kerberos-kdc"
        self.DeviceProxy = ""
        self.https_kerberos_portv6 = ""
        self.https_kerberos_port = ""
        self.https_kerberos_hostip = ""
        self.https_kerberos_hostipv6 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Https(A10BaseClass):
    
    """Class Description::
    HTTPS type.

    Class https supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param https_kerberos_realm: {"description": "Specify realm of Kerberos server", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param post_type: {"optional": true, "enum": ["postdata", "postfile"], "type": "string", "description": "'postdata': Specify the HTTP post data; 'postfile': Specify the HTTP post data; ", "format": "enum"}
    :param url_path: {"description": "Specify URL path, default is \"/\"", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 500, "type": "string"}
    :param https_username: {"description": "Specify the username", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param key_phrase: {"description": "Password Phrase", "format": "password", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param https_postdata: {"description": "Specify the HTTP post data (Input post data here)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param https_key_encrypted: {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param https_expect: {"default": 0, "optional": true, "type": "number", "description": "Specify what you expect from the response message", "format": "flag"}
    :param https: {"default": 0, "optional": true, "type": "number", "description": "HTTPS type", "format": "flag"}
    :param https_host: {"description": "Specify \"Host:\" header used in request (enclose IPv6 address in [])", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param key_pass_phrase: {"default": 0, "optional": true, "type": "number", "description": "Client private key password phrase", "format": "flag"}
    :param https_encrypted: {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param url_type: {"optional": true, "enum": ["GET", "POST", "HEAD"], "type": "string", "description": "'GET': HTTP GET method; 'POST': HTTP POST method; 'HEAD': HTTP HEAD method; ", "format": "enum"}
    :param web_port: {"description": "Specify HTTPS port (Port Number (default 443))", "format": "number", "default": 443, "optional": true, "maximum": 65534, "minimum": 1, "type": "number"}
    :param disable_sslv2hello: {"default": 0, "optional": true, "type": "number", "description": "Disable SSLv2Hello for HTTPs", "format": "flag"}
    :param key: {"description": "Specify client private key (Key name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param https_password_string: {"description": "help Configure password, '' means empty passworddd", "format": "password", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param post_path: {"description": "Specify URL path, default is \"/\"", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 500, "type": "string"}
    :param https_postfile: {"description": "Specify the HTTP post data (Input post data file name here)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param https_password: {"default": 0, "optional": true, "type": "number", "description": "Specify the user password", "format": "flag"}
    :param cert: {"description": "Specify client certificate (Certificate name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param https_text: {"description": "Specify text expected", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "not": "https-response-code", "type": "string"}
    :param https_response_code: {"description": "Specify response code range (e.g. 200,400-430) (Format is xx,xx-xx (xx between [100, 899])", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 31, "not": "https-text", "type": "string"}
    :param https_kerberos_auth: {"default": 0, "optional": true, "type": "number", "description": "Https Kerberos Auth", "format": "flag"}
    :param https_maintenance_code: {"description": "Specify response code for maintenance (Format is xx,xx-xx (xx between [100, 899])", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param https_url: {"default": 0, "optional": true, "type": "number", "description": "Specify URL string, default is GET /", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/health/monitor/{name}/method/https`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "https"
        self.a10_url="/axapi/v3/health/monitor/{name}/method/https"
        self.DeviceProxy = ""
        self.https_kerberos_realm = ""
        self.post_type = ""
        self.url_path = ""
        self.https_username = ""
        self.key_phrase = ""
        self.https_postdata = ""
        self.https_key_encrypted = ""
        self.https_expect = ""
        self.https = ""
        self.https_host = ""
        self.key_pass_phrase = ""
        self.https_encrypted = ""
        self.url_type = ""
        self.web_port = ""
        self.disable_sslv2hello = ""
        self.https_kerberos_kdc = {}
        self.key = ""
        self.https_password_string = ""
        self.post_path = ""
        self.https_postfile = ""
        self.https_password = ""
        self.cert = ""
        self.https_text = ""
        self.https_response_code = ""
        self.https_kerberos_auth = ""
        self.https_maintenance_code = ""
        self.https_url = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class DefaultInformation(A10BaseClass):
    
    """Class Description::
    Control distribution of default information.

    Class default-information supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param always: {"default": 0, "optional": true, "type": "number", "description": "Always advertise default route", "format": "flag"}
    :param metric: {"description": "OSPF default metric (OSPF metric)", "format": "number", "type": "number", "maximum": 16777214, "minimum": 0, "optional": true}
    :param originate: {"default": 0, "optional": true, "type": "number", "description": "Distribute a default route", "format": "flag"}
    :param metric_type: {"description": "OSPF metric type for default routes", "format": "number", "default": 2, "optional": true, "maximum": 2, "minimum": 1, "type": "number"}
    :param route_map: {"description": "Route map reference (Pointer to route-map entries)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/ospf/{process_id}/default-information`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "default-information"
        self.a10_url="/axapi/v3/router/ospf/{process_id}/default-information"
        self.DeviceProxy = ""
        self.always = ""
        self.metric = ""
        self.originate = ""
        self.metric_type = ""
        self.route_map = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param bad_hop_limit: {"description": "R.S. Bad Hop Limit", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "2"}
    :param bad_icmpv6_code: {"description": "R.S. Unknown ICMPv6 Code", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "2"}
    :param bad_icmpv6_csum: {"description": "R.S. Bad ICMPv6 Checksum", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "2"}
    :param truncated: {"description": "R.S. Truncated", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "2"}
    :param no_free_buffers: {"description": "No Free Buffers to send R.A.", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "2"}
    :param rate_limit: {"description": "R.S. Rate Limited", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "2"}
    :param l2_addr_and_unspec: {"description": "R.S. Src Link-Layer Option and Unspecified Address", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "2"}
    :param bad_icmpv6_option: {"description": "R.S. Bad ICMPv6 Option", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "2"}
    :param periodic_sent: {"description": "Periodic Router Advertisements (R.A.) Sent", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "2"}
    :param good_recv: {"description": "Good Router Solicitations (R.S.) Received", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "2"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.bad_hop_limit = ""
        self.bad_icmpv6_code = ""
        self.bad_icmpv6_csum = ""
        self.truncated = ""
        self.no_free_buffers = ""
        self.rate_limit = ""
        self.l2_addr_and_unspec = ""
        self.bad_icmpv6_option = ""
        self.periodic_sent = ""
        self.good_recv = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NdiscRa(A10BaseClass):
    
    """Class Description::
    Statistics for the object ndisc-ra.

    Class ndisc-ra supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/system/ndisc-ra/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ndisc-ra"
        self.a10_url="/axapi/v3/system/ndisc-ra/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Dns64(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param exclusive_answer: {"default": 0, "type": "number", "description": "Exclusive Answer in DNS Response", "format": "flag"}
    :param prefix: {"type": "string", "description": "IPv6 prefix", "format": "ipv6-address-plen"}
    :param disable: {"default": 0, "type": "number", "description": "Disable", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dns64"
        self.DeviceProxy = ""
        self.exclusive_answer = ""
        self.prefix = ""
        self.disable = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LidList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param request_limit: {"description": "Request limit (Specify request limit)", "format": "number", "type": "number", "maximum": 1048575, "minimum": 0, "optional": true}
    :param conn_limit: {"description": "Connection limit", "format": "number", "type": "number", "maximum": 1048575, "minimum": 0, "optional": true}
    :param interval: {"description": "Specify log interval in minutes, by default system will log every over limit instance", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}
    :param log: {"default": 0, "optional": true, "type": "number", "description": "Log a message", "format": "flag"}
    :param lidnum: {"description": "Specify a limit ID", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": false}
    :param request_rate_limit: {"description": "Request rate limit (Specify request rate limit)", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 1, "optional": true}
    :param conn_per: {"description": "Per (Specify interval in number of 100ms)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param request_per: {"description": "Per (Specify interval in number of 100ms)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param conn_rate_limit: {"description": "Specify connection rate limit", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 1, "optional": true}
    :param lockout: {"description": "Don't accept any new connection for certain time (Lockout duration in minutes)", "format": "number", "type": "number", "maximum": 1023, "minimum": 1, "optional": true}
    :param action_value: {"optional": true, "enum": ["forward", "reset"], "type": "string", "description": "'forward': Forward the traffic even it exceeds limit; 'reset': Reset the connection when it exceeds limit; ", "format": "enum"}
    :param over_limit_action: {"default": 0, "optional": true, "type": "number", "description": "Set action when exceeds limit", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "lid-list"
        self.DeviceProxy = ""
        self.request_limit = ""
        self.conn_limit = ""
        self.interval = ""
        self.log = ""
        self.dns64 = {}
        self.lidnum = ""
        self.request_rate_limit = ""
        self.conn_per = ""
        self.request_per = ""
        self.conn_rate_limit = ""
        self.lockout = ""
        self.action_value = ""
        self.over_limit_action = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ClassList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param header_name: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify L7 header name", "format": "string"}
    :param client_ip_l7_header: {"default": 0, "not": "client-ip-l3-dest", "type": "number", "description": "Use extract client IP address from L7 header", "format": "flag"}
    :param client_ip_l3_dest: {"default": 0, "not": "client-ip-l7-header", "type": "number", "description": "Use destination IP as client IP address", "format": "flag"}
    :param lid_list: {"minItems": 1, "items": {"type": "lid"}, "uniqueItems": true, "array": [{"required": ["lidnum"], "properties": {"request-limit": {"description": "Request limit (Specify request limit)", "format": "number", "type": "number", "maximum": 1048575, "minimum": 0, "optional": true}, "conn-limit": {"description": "Connection limit", "format": "number", "type": "number", "maximum": 1048575, "minimum": 0, "optional": true}, "interval": {"description": "Specify log interval in minutes, by default system will log every over limit instance", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "log": {"default": 0, "optional": true, "type": "number", "description": "Log a message", "format": "flag"}, "dns64": {"type": "object", "properties": {"exclusive-answer": {"default": 0, "type": "number", "description": "Exclusive Answer in DNS Response", "format": "flag"}, "prefix": {"type": "string", "description": "IPv6 prefix", "format": "ipv6-address-plen"}, "disable": {"default": 0, "type": "number", "description": "Disable", "format": "flag"}}}, "lidnum": {"description": "Specify a limit ID", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": false}, "request-rate-limit": {"description": "Request rate limit (Specify request rate limit)", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 1, "optional": true}, "conn-per": {"description": "Per (Specify interval in number of 100ms)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "request-per": {"description": "Per (Specify interval in number of 100ms)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "conn-rate-limit": {"description": "Specify connection rate limit", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 1, "optional": true}, "lockout": {"description": "Don't accept any new connection for certain time (Lockout duration in minutes)", "format": "number", "type": "number", "maximum": 1023, "minimum": 1, "optional": true}, "action-value": {"optional": true, "enum": ["forward", "reset"], "type": "string", "description": "'forward': Forward the traffic even it exceeds limit; 'reset': Reset the connection when it exceeds limit; ", "format": "enum"}, "over-limit-action": {"default": 0, "optional": true, "type": "number", "description": "Set action when exceeds limit", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/policy/{name}/class-list/lid/{lidnum}"}
    :param name: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Class list name or geo-location-class-list name", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "class-list"
        self.DeviceProxy = ""
        self.header_name = ""
        self.client_ip_l7_header = ""
        self.client_ip_l3_dest = ""
        self.lid_list = []
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class BwListId(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param pbslb_interval: {"description": "Specify logging interval in minutes", "format": "number", "default": 3, "maximum": 60, "minimum": 0, "type": "number"}
    :param action_interval: {"description": "Specify logging interval in minute (default is 3)", "format": "number", "default": 3, "maximum": 60, "minimum": 0, "type": "number"}
    :param service_group: {"description": "Specify a service group (Specify the service group name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "not": "bw-list-action", "type": "string", "$ref": "/axapi/v3/slb/service-group"}
    :param logging_drp_rst: {"default": 0, "type": "number", "description": "Configure PBSLB logging", "format": "flag"}
    :param fail: {"default": 0, "type": "number", "description": "Only log unsuccessful connections", "format": "flag"}
    :param pbslb_logging: {"default": 0, "type": "number", "description": "Configure PBSLB logging", "format": "flag"}
    :param id: {"description": "Specify id that maps to service group (The id number)", "minimum": 0, "type": "number", "maximum": 31, "format": "number"}
    :param bw_list_action: {"not": "service-group", "enum": ["drop", "reset"], "type": "string", "description": "'drop': drop the packet; 'reset': Send reset back; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "bw-list-id"
        self.DeviceProxy = ""
        self.pbslb_interval = ""
        self.action_interval = ""
        self.service_group = ""
        self.logging_drp_rst = ""
        self.fail = ""
        self.pbslb_logging = ""
        self.A10WW_id = ""
        self.bw_list_action = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Policy(A10BaseClass):
    
    """Class Description::
    Policy config.

    Class policy supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param use_destination_ip: {"default": 0, "optional": true, "type": "number", "description": "Use destination IP to match the policy", "format": "flag"}
    :param name: {"description": "Policy template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param over_limit: {"default": 0, "optional": true, "type": "number", "description": "Specify operation in case over limit", "format": "flag"}
    :param full_domain_tree: {"default": 0, "optional": true, "type": "number", "description": "Share counters between geo-location and sub regions", "format": "flag"}
    :param interval: {"description": "Log interval (minute)", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}
    :param share: {"default": 0, "optional": true, "type": "number", "description": "Share counters between virtual ports and virtual servers", "format": "flag"}
    :param over_limit_lockup: {"description": "Don't accept any new connection for certain time (Lockup duration (minute))", "format": "number", "type": "number", "maximum": 127, "minimum": 1, "optional": true}
    :param over_limit_logging: {"default": 0, "optional": true, "type": "number", "description": "Log a message", "format": "flag"}
    :param bw_list_id: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"pbslb-interval": {"description": "Specify logging interval in minutes", "format": "number", "default": 3, "maximum": 60, "minimum": 0, "type": "number"}, "action-interval": {"description": "Specify logging interval in minute (default is 3)", "format": "number", "default": 3, "maximum": 60, "minimum": 0, "type": "number"}, "service-group": {"description": "Specify a service group (Specify the service group name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "not": "bw-list-action", "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "logging-drp-rst": {"default": 0, "type": "number", "description": "Configure PBSLB logging", "format": "flag"}, "fail": {"default": 0, "type": "number", "description": "Only log unsuccessful connections", "format": "flag"}, "pbslb-logging": {"default": 0, "type": "number", "description": "Configure PBSLB logging", "format": "flag"}, "optional": true, "id": {"description": "Specify id that maps to service group (The id number)", "minimum": 0, "type": "number", "maximum": 31, "format": "number"}, "bw-list-action": {"not": "service-group", "enum": ["drop", "reset"], "type": "string", "description": "'drop': drop the packet; 'reset': Send reset back; ", "format": "enum"}}}]}
    :param bw_list_name: {"description": "Specify a blacklist/whitelist name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param overlap: {"default": 0, "optional": true, "type": "number", "description": "Use overlap mode for geo-location to do longest match", "format": "flag"}
    :param timeout: {"description": "Define timeout value of PBSLB dynamic entry (Timeout value (minute, default is 5))", "format": "number", "type": "number", "maximum": 127, "minimum": 1, "optional": true}
    :param over_limit_reset: {"default": 0, "optional": true, "type": "number", "description": "Reset the connection when it exceeds limit", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/policy/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "policy"
        self.a10_url="/axapi/v3/slb/template/policy/{name}"
        self.DeviceProxy = ""
        self.use_destination_ip = ""
        self.name = ""
        self.over_limit = ""
        self.class_list = {}
        self.full_domain_tree = ""
        self.interval = ""
        self.share = ""
        self.over_limit_lockup = ""
        self.over_limit_logging = ""
        self.bw_list_id = []
        self.bw_list_name = ""
        self.overlap = ""
        self.timeout = ""
        self.over_limit_reset = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class VipServerV6(A10BaseClass):
    
    """Class Description::
    Specify a VIP for the SLB device.

    Class vip-server-v6 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ipv6: {"optional": false, "type": "string", "description": "Specify IP address (IPv6 address)", "format": "ipv6-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/site/{site_name}/slb-dev/{device_name}/vip-server/vip-server-v6/{ipv6}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ipv6"]

        self.b_key = "vip-server-v6"
        self.a10_url="/axapi/v3/gslb/site/{site_name}/slb-dev/{device_name}/vip-server/vip-server-v6/{ipv6}"
        self.DeviceProxy = ""
        self.ipv6 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Cookie(A10BaseClass):
    
    """Class Description::
    Cookie persistence.

    Class cookie supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param domain: {"description": "Set cookie domain", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param secure: {"default": 0, "optional": true, "type": "number", "description": "Enable secure attribute", "format": "flag"}
    :param cookie_name: {"description": "Set cookie name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param dont_honor_conn_rules: {"default": 0, "optional": true, "type": "number", "description": "Do not observe connection rate rules", "format": "flag"}
    :param server: {"description": "Persist to the same server, default is port", "format": "flag", "default": 0, "optional": true, "not": "service-group", "type": "number"}
    :param server_service_group: {"default": 0, "optional": true, "type": "number", "description": "Persist to the same server and within the same service group", "format": "flag"}
    :param service_group: {"description": "Persist within the same service group", "format": "flag", "default": 0, "optional": true, "not": "server", "type": "number"}
    :param expire: {"description": "Set cookie expiration time (Expiration in seconds)", "format": "number", "default": 0, "optional": true, "maximum": 31536000, "minimum": 0, "type": "number"}
    :param match_type: {"default": 0, "optional": true, "type": "number", "description": "Persist for server, default is port", "format": "flag"}
    :param path: {"description": "Set cookie path (Cookie path, default is \"/\")", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param pass_thru: {"default": 0, "optional": true, "type": "number", "description": "Pass thru mode - Server sends the persist cookie", "format": "flag"}
    :param scan_all_members: {"default": 0, "optional": true, "type": "number", "description": "Persist within the same server SCAN", "format": "flag"}
    :param insert_always: {"default": 0, "optional": true, "type": "number", "description": "Insert persist cookie to every reponse", "format": "flag"}
    :param httponly: {"default": 0, "optional": true, "type": "number", "description": "Enable HttpOnly attribute", "format": "flag"}
    :param name: {"description": "Cookie persistence (Cookie persistence template name)", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/persist/cookie/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "cookie"
        self.a10_url="/axapi/v3/slb/template/persist/cookie/{name}"
        self.DeviceProxy = ""
        self.domain = ""
        self.secure = ""
        self.cookie_name = ""
        self.dont_honor_conn_rules = ""
        self.server = ""
        self.server_service_group = ""
        self.service_group = ""
        self.expire = ""
        self.match_type = ""
        self.path = ""
        self.pass_thru = ""
        self.scan_all_members = ""
        self.insert_always = ""
        self.httponly = ""
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Nat(A10BaseClass):
    
    """Class Description::
    Configure IPv6 NAT.

    Class nat supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param pool_group_list: {"minItems": 1, "items": {"type": "pool-group"}, "uniqueItems": true, "array": [{"required": ["pool-group-name"], "properties": {"member-list": {"minItems": 1, "items": {"type": "member"}, "uniqueItems": true, "array": [{"required": ["pool-name"], "properties": {"pool-name": {"description": "Specify NAT pool name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/ipv6/nat/pool-group/{pool-group-name}/member/{pool-name}"}, "pool-group-name": {"description": "Specify pool group name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "vrid": {"description": "Specify VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "modify-not-allowed": 1, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/ipv6/nat/pool-group/{pool-group-name}"}
    :param pool_list: {"minItems": 1, "items": {"type": "pool"}, "uniqueItems": true, "array": [{"required": ["pool-name"], "properties": {"start-address": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Configure start IP address of NAT pool", "format": "ipv6-address"}, "vrid": {"description": "Specify VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "modify-not-allowed": 1, "type": "number"}, "netmask": {"description": "Configure mask for pool", "format": "number", "optional": true, "maximum": 128, "minimum": 64, "modify-not-allowed": 1, "type": "number"}, "end-address": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Configure end IP address of NAT pool", "format": "ipv6-address"}, "ip-rr": {"description": "Use IP address round-robin behavior", "format": "flag", "default": 0, "type": "number", "modify-not-allowed": 1, "optional": true}, "gateway": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Configure gateway IP", "format": "ipv6-address"}, "pool-name": {"description": "Specify pool name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/ipv6/nat/pool/{pool-name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ipv6/nat`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "nat"
        self.a10_url="/axapi/v3/ipv6/nat"
        self.DeviceProxy = ""
        self.icmpv6 = {}
        self.pool_group_list = []
        self.inside = {}
        self.pool_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ntp(A10BaseClass):
    
    """Class Description::
    Network Time Protocol configuration.

    Class ntp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param auth_key_list: {"minItems": 1, "items": {"type": "auth-key"}, "uniqueItems": true, "array": [{"required": ["key"], "properties": {"encrypted": {"not": "hex-encrypted", "optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "key-type": {"optional": true, "enum": ["ascii", "hex"], "type": "string", "description": "'ascii': key string in ASCII form; 'hex': key string in hex form; ", "format": "enum"}, "hex-encrypted": {"not": "encrypted", "optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "hex-key": {"format": "password", "minLength": 21, "optional": true, "maxLength": 40, "not": "asc-key", "type": "string"}, "alg-type": {"optional": true, "enum": ["M", "SHA", "SHA1"], "type": "string", "description": "'M': encryption using MD5; 'SHA': encryption using SHA; 'SHA1': encryption using SHA1; ", "format": "enum"}, "key": {"description": "authentication key", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}, "asc-key": {"format": "password", "minLength": 1, "optional": true, "maxLength": 20, "not": "hex-key", "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/ntp/auth-key/{key}"}
    :param trusted_key_list: {"minItems": 1, "items": {"type": "trusted-key"}, "uniqueItems": true, "array": [{"required": ["key"], "properties": {"key": {"description": "trusted key", "format": "number", "optional": false, "maximum": 65535, "minimum": 1, "type": "number", "$ref": "/axapi/v3/ntp/auth-key"}}}], "type": "array", "$ref": "/axapi/v3/ntp/trusted-key/{key}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ntp`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ntp"
        self.a10_url="/axapi/v3/ntp"
        self.DeviceProxy = ""
        self.auth_key_list = []
        self.trusted_key_list = []
        self.server = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param state: {"enum": ["UP", "DOWN", "DELETE", "DISABLED", "MAINTENANCE"], "type": "string", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.state = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Server(A10BaseClass):
    
    """Class Description::
    Operational Status for the object server.

    Class server supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param port_list: {"minItems": 1, "items": {"type": "port"}, "uniqueItems": true, "array": [{"required": ["port-number", "protocol"], "properties": {"oper": {"type": "object", "properties": {"alloc_failed": {"type": "number", "format": "number"}, "vrid": {"enum": ["default"], "type": "string", "format": "enum"}, "ha_group_id": {"enum": ["default"], "type": "string", "format": "enum"}, "ip": {"type": "string", "format": "ipv4-address"}, "ports_consumed": {"type": "number", "format": "number"}, "state": {"enum": ["UP", "DOWN", "DELETE", "DISABLED", "MAINTENANCE"], "type": "string", "format": "enum"}, "ipv6": {"type": "string", "format": "ipv6-address"}, "ports_freed_total": {"type": "number", "format": "number"}, "ports_consumed_total": {"type": "number", "format": "number"}}}, "protocol": {"enum": ["tcp", "udp"], "description": "'tcp': TCP Port; 'udp': UDP Port; ", "format": "enum", "type": "string", "oid": "1002", "optional": false}, "port-number": {"description": "Port Number", "format": "number", "optional": false, "oid": "1001", "maximum": 65534, "minimum": 0, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/slb/server/{name}/port/{port-number}+{protocol}"}
    :param name: {"description": "Server Name", "format": "string-rlx", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/server/{name}/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "server"
        self.a10_url="/axapi/v3/slb/server/{name}/oper"
        self.DeviceProxy = ""
        self.oper = {}
        self.port_list = []
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param state: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.state = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Zone(A10BaseClass):
    
    """Class Description::
    Operational Status for the object zone.

    Class zone supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param service_list: {"minItems": 1, "items": {"type": "service"}, "uniqueItems": true, "array": [{"required": ["service-port", "service-name"], "properties": {"oper": {"type": "object", "properties": {"total-sessions": {"type": "number", "format": "number"}, "cache-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cache-ttl": {"type": "number", "format": "number"}, "additional-records": {"type": "number", "format": "number"}, "question-records": {"type": "number", "format": "number"}, "cache-dns-flag": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "answer-records": {"type": "number", "format": "number"}, "alias": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "cache-length": {"type": "number", "format": "number"}, "optional": true, "authority-records": {"type": "number", "format": "number"}}}]}, "state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "session-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"aging": {"type": "number", "format": "number"}, "hits": {"type": "number", "format": "number"}, "update": {"type": "number", "format": "number"}, "client": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "last-second-hits": {"type": "number", "format": "number"}, "mode": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "ttl": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true, "best": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}]}, "matched": {"type": "number", "format": "number"}}}, "dns-a-record": {"type": "object", "properties": {"oper": {"type": "object", "properties": {}}}}, "dns-ns-record-list": {"minItems": 1, "items": {"type": "dns-ns-record"}, "uniqueItems": true, "array": [{"required": ["ns-name"], "properties": {"oper": {"type": "object", "properties": {"last-server": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}, "ns-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/dns-mx-record/{mx-name}/dns-ns-record/{ns-name}/service/{service-port}+{service-name}/dns-mx-record/{mx-name}/dns-ns-record/{ns-name}"}, "service-port": {"description": "Port number of the service", "format": "number", "optional": false, "oid": "1001", "maximum": 65534, "minimum": 0, "type": "number"}, "dns-mx-record-list": {"minItems": 1, "items": {"type": "dns-mx-record"}, "uniqueItems": true, "array": [{"required": ["mx-name"], "properties": {"oper": {"type": "object", "properties": {"last-server": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}, "mx-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/dns-mx-record/{mx-name}/dns-ns-record/{ns-name}/service/{service-port}+{service-name}/dns-mx-record/{mx-name}"}, "service-name": {"description": "Specify the service name for the zone, * for wildcard", "format": "string-rlx", "minLength": 1, "oid": "1002", "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/dns-mx-record/{mx-name}/dns-ns-record/{ns-name}/service/{service-port}+{service-name}"}
    :param dns_mx_record_list: {"minItems": 1, "items": {"type": "dns-mx-record"}, "uniqueItems": true, "array": [{"required": ["mx-name"], "properties": {"oper": {"type": "object", "properties": {"last-server": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}, "mx-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/dns-mx-record/{mx-name}"}
    :param name: {"description": "Specify the name for the DNS zone", "format": "string-rlx", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}
    :param dns_ns_record_list: {"minItems": 1, "items": {"type": "dns-ns-record"}, "uniqueItems": true, "array": [{"required": ["ns-name"], "properties": {"oper": {"type": "object", "properties": {"last-server": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}, "ns-name": {"description": "Specify Domain Name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/dns-mx-record/{mx-name}/dns-ns-record/{ns-name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/zone/{name}/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "zone"
        self.a10_url="/axapi/v3/gslb/zone/{name}/oper"
        self.DeviceProxy = ""
        self.oper = {}
        self.service_list = []
        self.dns_mx_record_list = []
        self.name = ""
        self.dns_ns_record_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class DeleteCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param store_name_del: {"minLength": 1, "maxLength": 31, "type": "string", "description": "profile name for deleting", "format": "string"}
    :param delete: {"default": 0, "type": "number", "description": "Delete store", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "delete-cfg"
        self.DeviceProxy = ""
        self.store_name_del = ""
        self.delete = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CreatCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param create: {"default": 0, "type": "number", "description": "Create store", "format": "flag"}
    :param remote_file: {"type": "string", "description": "profile name for remote url", "format": "url"}
    :param store_name: {"minLength": 1, "maxLength": 31, "type": "string", "description": "profile name to store remote url", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "creat-cfg"
        self.DeviceProxy = ""
        self.create = ""
        self.remote_file = ""
        self.store_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Store(A10BaseClass):
    
    """    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Save backup store information.

    Class store supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/backup/store`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "store"
        self.a10_url="/axapi/v3/backup/store"
        self.DeviceProxy = ""
        self.delete_cfg = {}
        self.creat_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Smpp(A10BaseClass):
    
    """Class Description::
    SMPP template.

    Class smpp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "SMPP Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param server_enquire_link: {"default": 0, "optional": true, "type": "number", "description": "Send server ENQUIRE_LINK packet for every persist connection when enable conn-reuse", "format": "flag"}
    :param server_selection_per_request: {"default": 0, "optional": true, "type": "number", "description": "Force server selection on every SMPP request when enable conn-reuse", "format": "flag"}
    :param client_enquire_link: {"default": 0, "optional": true, "type": "number", "description": "Respond client ENQUIRE_LINK packet directly instead of forwarding to server", "format": "flag"}
    :param server_enquire_link_val: {"description": "Set interval of keep-alive packet for each persistent connection (second, default is 30)", "format": "number", "default": 30, "optional": true, "maximum": 300, "minimum": 5, "type": "number"}
    :param user: {"description": "Configure the user to bind (The name used to bind)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param password: {"description": "Configure the password used to bind", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/smpp/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "smpp"
        self.a10_url="/axapi/v3/slb/template/smpp/{name}"
        self.DeviceProxy = ""
        self.name = ""
        self.server_enquire_link = ""
        self.server_selection_per_request = ""
        self.client_enquire_link = ""
        self.server_enquire_link_val = ""
        self.user = ""
        self.password = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class OspfInlineCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ospf_inline: {"default": 0, "partition-visibility": "shared", "type": "number", "description": "Enable OSPF under Layer 3 Inline Hot Standby Mode", "format": "flag"}
    :param vlan: {"description": "Do not filter OSPF packet on specific vlan (Vlan number)", "minimum": 1, "type": "number", "maximum": 4094, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ospf-inline-cfg"
        self.DeviceProxy = ""
        self.ospf_inline = ""
        self.vlan = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class L2InlinePeerIpCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param l2_inline_peer_ip: {"default": 0, "partition-visibility": "shared", "type": "number", "description": "Peer IP for Layer 2 inline mode", "format": "flag"}
    :param ip_address: {"type": "string", "description": "IP address (IPv4 address)", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "l2-inline-peer-ip-cfg"
        self.DeviceProxy = ""
        self.l2_inline_peer_ip = ""
        self.ip_address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class HostidAppendToVrid(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param hostid_append_to_vrid_value: {"description": "hostid append to vrid num", "partition-visibility": "shared", "format": "number", "maximum": 31, "minimum": 1, "not": "hostid-append-to-vrid-default", "type": "number"}
    :param hostid_append_to_vrid_default: {"description": "hostid append to vrid default", "partition-visibility": "shared", "default": 0, "format": "flag", "not": "hostid-append-to-vrid-value", "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "hostid-append-to-vrid"
        self.DeviceProxy = ""
        self.hostid_append_to_vrid_value = ""
        self.hostid_append_to_vrid_default = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class InlineModeCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param inline_mode: {"default": 0, "partition-visibility": "shared", "type": "number", "description": "Enable Layer 2 Inline Hot Standby Mode", "format": "flag"}
    :param preferred_trunk: {"not": "preferred-port", "type": "number", "description": "Preferred trunk Port", "format": "interface"}
    :param preferred_port: {"not": "preferred-trunk", "type": "number", "description": "Preferred ethernet Port", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "inline-mode-cfg"
        self.DeviceProxy = ""
        self.inline_mode = ""
        self.preferred_trunk = ""
        self.preferred_port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Common(A10BaseClass):
    
    """Class Description::
    HA VRRP-A Global Commands.

    Class common supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param enable: {"description": "Enable vrrp HA", "partition-visibility": "shared", "default": 0, "type": "number", "format": "flag", "optional": true}
    :param hello_interval: {"description": "VRRP-A Hello Interval (1-255, in unit of 100millisec, default is 2)", "partition-visibility": "shared", "default": 2, "optional": true, "format": "number", "maximum": 255, "minimum": 1, "type": "number"}
    :param preemption_delay: {"description": "Delay before changing state from Active to Standby (1-255, in unit of 100millisec, default is 60)", "partition-visibility": "shared", "default": 60, "optional": true, "format": "number", "maximum": 255, "minimum": 1, "type": "number"}
    :param set_id: {"description": "Set-ID for HA configuration (Set id from 1 to 15)", "partition-visibility": "shared", "optional": true, "format": "number", "maximum": 15, "minimum": 1, "type": "number"}
    :param device_id: {"description": "Unique ID for each VRRP-A box (Device-id number)", "partition-visibility": "shared", "optional": true, "format": "number", "maximum": 8, "minimum": 1, "type": "number"}
    :param arp_retry: {"description": "Number of additional gratuitous ARPs sent out after HA failover (1-255, default is 4)", "partition-visibility": "shared", "default": 4, "optional": true, "format": "number", "maximum": 255, "minimum": 1, "type": "number"}
    :param dead_timer: {"description": "VRRP-A dead timer in terms of how many hello messages missed, default is 5 (2-255, default is 5)", "partition-visibility": "shared", "default": 5, "optional": true, "format": "number", "maximum": 255, "minimum": 2, "type": "number"}
    :param disable_default_vrid: {"description": "Disable default vrid", "partition-visibility": "shared", "default": 0, "type": "number", "format": "flag", "optional": true}
    :param l3_inline_mode: {"description": "Enable Layer 3 Inline Hot Standby Mode", "partition-visibility": "shared", "default": 0, "type": "number", "format": "flag", "optional": true}
    :param track_event_delay: {"description": "Delay before changing state after up/down event (Units of 100 milliseconds (default 30))", "partition-visibility": "shared", "default": 30, "optional": true, "format": "number", "maximum": 100, "minimum": 1, "type": "number"}
    :param restart_time: {"description": "Time between restarting ports on standby system after transition", "partition-visibility": "shared", "default": 20, "optional": true, "format": "number", "maximum": 100, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vrrp-a/common`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "common"
        self.a10_url="/axapi/v3/vrrp-a/common"
        self.DeviceProxy = ""
        self.ospf_inline_cfg = {}
        self.enable = ""
        self.hello_interval = ""
        self.preemption_delay = ""
        self.set_id = ""
        self.device_id = ""
        self.arp_retry = ""
        self.l2_inline_peer_ip_cfg = {}
        self.dead_timer = ""
        self.disable_default_vrid = ""
        self.l3_inline_mode = ""
        self.track_event_delay = ""
        self.hostid_append_to_vrid = {}
        self.restart_time = ""
        self.inline_mode_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


